<template>
  <b-row>
    <b-col cols="12" v-if="promotion.id">
      <b-form-group
        label="編號"
        label-cols-md="1"
        class="text-left"
        label-size="lg"
      >
        <b-form-input :value="promotion.id" disabled="disabled" />
      </b-form-group>
    </b-col>

    <b-col cols="12">
      <b-form-group
        label="*優惠名稱"
        label-cols-md="1"
        class="text-left"
        label-size="lg"
      >
        <b-form-input v-model="promotion.name" placeholder="請輸入優惠名稱" />
        <small class="text-danger" v-for="error in strErrors.name" :key="error"
          >{{ error }}<br
        /></small>
      </b-form-group>
    </b-col>

    <b-col cols="12">
      <b-form-group
        label="*活動起訖日期"
        label-for="start_at"
        label-cols-md="1"
        class="text-left"
        label-size="lg"
      >
        <b-col class="col-md-3 d-inline-block pl-0">
          <label class="d-inline">開始時間</label>
          <flat-pickr
            v-model="promotion.start_at"
            id="start_at"
            class="form-control"
            :config="{ enableTime: true, dateFormat: 'Y-m-d H:i:S' }"
          />
        </b-col>
        <b-col class="col-md-3 d-inline-block pl-0">
          <label class="d-inline">結束時間</label>
          <flat-pickr
            v-model="promotion.end_at"
            id="end_at"
            class="form-control"
            :config="{ enableTime: true, dateFormat: 'Y-m-d H:i:S' }"
          />
        </b-col>
        <br />
        <small
          class="text-danger"
          v-for="error in strErrors.start_at"
          :key="error"
          >{{ error }}<br
        /></small>
        <small
          class="text-danger"
          v-for="error in strErrors.end_at"
          :key="error"
          >{{ error }}<br
        /></small>
      </b-form-group>
    </b-col>

    <b-col cols="12">
      <b-form-group
        label="優惠說明"
        label-for="description"
        label-cols-md="1"
        class="text-left"
        label-size="lg"
      >
        <b-form-textarea
          v-model="promotion.description"
          id="description"
          placeholder="請輸入優惠說明，文字長度不超過1000字。"
          rows="6"
        />
        <small
          class="text-danger"
          v-for="error in strErrors.description"
          :key="error"
          >{{ error }}<br
        /></small>
      </b-form-group>
    </b-col>

    <b-col cols="12">
      <b-form-group
        label="排除條件"
        label-cols-md="1"
        class="text-left"
        label-size="lg"
      >
        <v-select
          v-model="promotion.excepts"
          :options="excepts"
          :clearable="true"
          :multiple="true"
          :reduce="(freight) => freight.id"
          label="name"
          class="item-selector-title"
        />
        <small
          class="text-danger"
          v-for="error in strErrors.excepts"
          :key="error"
          >{{ error }}<br
        /></small>
      </b-form-group>
    </b-col>

    <b-col cols="12">
      <b-form-group
        label="*適用渠道"
        label-for="firm-captcha-num"
        label-cols-md="1"
        class="text-left"
        label-size="lg"
      >
        <b-button
          v-ripple.400="'rgba(113, 102, 240, 0.15)'"
          class="mt-1"
          variant="outline-primary"
          @click="applyAllChannels"
        >
          全選
        </b-button>
        <b-form-checkbox-group
          v-model="promotion.apply_channels"
          name="flavour-2"
          class="demo-inline-spacing"
        >
          <b-form-checkbox
            :value="channel"
            :key="channel.id"
            v-for="channel in channels"
            class="custom-control-primary"
          >
            {{ channel.name }}
          </b-form-checkbox>
        </b-form-checkbox-group>
        <small class="text-danger">{{ strErrors.channels }}</small>
      </b-form-group>
    </b-col>
  </b-row>
</template>

<script>
import Ripple from "vue-ripple-directive";
import vSelect from "vue-select";
import flatPickr from "vue-flatpickr-component";
import axios from "axios";
import "flatpickr/dist/flatpickr.css";

export default {
  components: {
    vSelect,
    flatPickr,
  },
  directives: {
    Ripple,
  },
  props: {
    promotion: {
      type: Object,
      default: () => {
        return {
          id: null,
          name: null,
          start_at: null,
          end_at: null,
          description: null,
          apply_channels: [],
          excepts: [],
        };
      },
    },
    strErrors: {
      type: Object,
      default: () => {
        return {
          name: null,
          start_at: null,
          end_at: null,
          description: null,
          apply_channels: null,
          excepts: null,
        };
      },
    },
  },
  data() {
    return {
      channels: [],
      excepts: [],
    };
  },
  mounted() {
    this.getChannels();
    this.getExcepts();
  },
  methods: {
    /**
     * 全選渠道
     */
    applyAllChannels() {
      if (this.promotion.apply_channels.length === this.channels.length) {
        this.promotion.apply_channels = [];
      } else {
        this.promotion.apply_channels = this.channels;
      }
    },

    /**
     * 取得渠道
     */
    getChannels() {
      axios.get("/api/v1/promotions/channels").then((response) => {
        this.channels = response.data?.data;

        this.$emit("initChannels", response.data?.data);
      });
    },

    /**
     * 取得排除條件
     * @todo 數量變多後可以考慮改接API
     */
    getExcepts() {
      this.excepts = [{ id: 1, name: "coupon" }];
    },
  },
};
</script>
<style lang="scss">
@import "~@resources/scss/vue/libs/quill.scss";
@import "~@resources/scss/vue/libs/vue-sweetalert.scss";
</style>